from langchain_core.document_loaders import BaseLoader


class WatsonSpeechToTextLoader(BaseLoader):
    """Transcribe audio ducuments using IBM Watson Speech-to-Text.

    References:
        [1] https://www.ibm.com/products/speech-to-text
        [2] https://cloud.ibm.com/apidocs/speech-to-text?code=python
    """

    pass



from langchain_core.retrievers import BaseRetriever


class WatsonDiscoveryRetriever(BaseRetriever):
    """IBM Watson Discovery retriever.

    References:
        [1] https://www.ibm.com/products/watson-discovery
        [2] https://cloud.ibm.com/apidocs/discovery-data?code=python
    """

    pass



from langchain_core.documents import BaseDocumentTransformer


class WatsonLanguageTranslatorTransformer(BaseDocumentTransformer):
    """Translate text documents using IBM Watson Language Translator.

    References:
        [1] https://cloud.ibm.com/apidocs/language-translator?code=python
    """

    pass



from langchain_core.documents import Document
from langchain_core.stores import BaseStore


class WatsonDiscoveryStore(BaseStore[str, Document]):
    """IBM Watson Discovery store.

    References:
        [1] https://www.ibm.com/products/watson-discovery
        [2] https://cloud.ibm.com/apidocs/discovery-data?code=python
    """

    pass



from langchain_core.tools import BaseTool


class WatsonTextToSpeechTool(BaseTool):
    """Tool that queries the IBM Watson Text-to-Speech API.

    References:
        [1] https://www.ibm.com/products/text-to-speech
        [2] https://cloud.ibm.com/apidocs/text-to-speech?code=python
    """

    pass
